
reset

set encoding utf8
set terminal svg enhanced size 1200,800 font 'Sans,20'

# -----------------------------------------------------------------------------
#   Units, calibrations and conversions
# -----------------------------------------------------------------------------

unit = 1e9 # For nanoampere plotting instead of ampere

# This is what I know for sure:

clockfrequency = 120e6
repetitions = 1

# Rough estimations: Vcc of 3.3 V; GPIO input low-going hysteresis thereshold of 0.35*Vcc and 20 pF total capacitance

u0   = 3.3
ulow = 1.16
cap = 20e-12

# 120 MHz, measured 2697 cycles for one parallel loop run, 14 cycles for one singular loop run.
# Column 0: Minutes. Columns 1-18: LEDs, parallel run. Columns 19-36: LEDs, singular run.

current(x) = (unit * cap * (u0 - ulow) / (x*14/clockfrequency/repetitions) )

# Wavelength calibration of the emission spectra

offset = 0.441

# Wavelength calibration of the sensitivity measurement setup

scale(x) = (-x - 1150)*(702 - 633)/(1482 - 1150) + 633

filtercutoff = 482

# -----------------------------------------------------------------------------
#   Deltazacke für die Emissionswellenlänge
# -----------------------------------------------------------------------------

lorentz(x, Gamma) = 1/(pi*Gamma) * Gamma**2 / (x**2 + Gamma **2)

# -----------------------------------------------------------------------------
#   Wavelength calibration of the sensitivity measurement setup
# -----------------------------------------------------------------------------

set samples 10000

set key left

set xlabel "Wavelength [nm]"

set ytics nomirror
set y2tics nomirror

set ylabel "Estimated photo current [nA]"
set y2label "Laser intensity [arb. unit]"

set xrange [350:800]

set output "Calibration-HeNe.svg"

plot lorentz(x-632.8, 1/pi) axes x1y2 lt rgb "red" title "Helium-Neon Laser 632.8 nm", \
     "Calibration-HeNe.dat" u (scale($1)):( current($3) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "BPW34: Helium-Neon Laser",\
     "Calibration-HeNe-Fine.dat" u (scale($1)):( current($3) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "steelblue" title "BPW34: Finer Resolution"

set y2label "Neon intensity [arb. unit]"

set output "Calibration-Neon.svg"

plot "Neon-400-1200nm.asc" u ($1 + offset):($1>filtercutoff?$2:1/0) w l axes x1y2 lt rgb "violet" title "Neon reference", \
     "Calibration-Neon.dat" u (scale($1)):( current($3) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "BPW34: Neon Glow Lamp"

set key right
set autoscale x

# -----------------------------------------------------------------------------
#   Measurement results
# -----------------------------------------------------------------------------

set ylabel "Estimated LED photo current [nA]"
set y2label "Emission intensity [arb. unit]"

set xrange[350:1000]

set output "Sensitivity-00.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==0 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "00 Infrared Sensitivity SFH 4346", \
     lorentz(x-950, 1/pi) axes x1y2 lt rgb "red" title "00 Infrared Emission 950 nm"

set output "Sensitivity-01.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==1 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "01 Infrared Sensitivity SFH 4356P", \
     lorentz(x-860, 1/pi) axes x1y2 lt rgb "red" title "01 Infrared Emission 860 nm"

set xrange[350:800]

set output "Sensitivity-02.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==2 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "02 Red Sensitivity RND 135-00006", \
     lorentz(x-700, 1/pi) axes x1y2 lt rgb "red" title "02 Red Emission 700 nm"

set output "Sensitivity-03.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==3 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "03 Red Sensitivity LED 3-3500 RT", \
     lorentz(x-660, 1/pi) axes x1y2 lt rgb "red" title "03 Red Emission 660 nm"

set output "Sensitivity-04.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==4 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "04 Red Sensitivity LED 3-4500 RT", \
     lorentz(x-660, 1/pi) axes x1y2 lt rgb "red" title "04 Red Emission 660 nm"

set output "Sensitivity-05.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==5 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "05 Red Sensitivity EVL 264-7SDRC", \
     lorentz(x-650, 1/pi) axes x1y2 lt rgb "red" title "05 Red Emission 650 nm"

set output "Sensitivity-06.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==6 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "06 Red Sensitivity KBT L-7104SURC", \
     lorentz(x-640, 1/pi) axes x1y2 lt rgb "red" title "06 Red Emission 640 nm"

set output "Sensitivity-07.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==7 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "07 Red Sensitivity KBT L-7104SEC-H", \
     lorentz(x-635, 1/pi) axes x1y2 lt rgb "red" title "07 Red Emission 635 nm"

set output "Sensitivity-08.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==8 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "08 Red Sensitivity VIS TLHR 4900", \
     lorentz(x-635, 1/pi) axes x1y2 lt rgb "red" title "08 Red Emission 635 nm"

set output "Sensitivity-09.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==9 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "09 Red Sensitivity SLK 3MM RT", \
     lorentz(x-627, 1/pi) axes x1y2 lt rgb "red" title "09 Red Emission 627 nm"

set output "Sensitivity-10.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==10 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "10 Green Sensitivity WUE 151034GS0300 ", \
     lorentz(x-525, 1/pi) axes x1y2 lt rgb "red" title "10 Green Emission 525 nm"

set output "Sensitivity-11.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==11 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "11 Orange Sensitivity LED 3-7800 OR", \
     lorentz(x-611, 1/pi) axes x1y2 lt rgb "red" title "11 Orange Emission 611 nm"

set output "Sensitivity-12.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==12 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "12 Orange Sensitivity LED 3-3000L ONG", \
     lorentz(x-605, 1/pi) axes x1y2 lt rgb "red" title "12 Orange Emission 605 nm"

set output "Sensitivity-13.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==13 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "13 Yellow Sensitivity LED 3-2800 GE", \
     lorentz(x-590, 1/pi) axes x1y2 lt rgb "red" title "13 Yellow Emission 590 nm"


set output "Sensitivity-14.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==14 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "14 Yellow Sensitivity NTE NTE30032", \
     lorentz(x-592, 1/pi) axes x1y2 lt rgb "red" title "14 Yellow Emission 592 nm"

set output "Sensitivity-15.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==15 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "15 Yellow Sensitivity LED 3-1300 GE", \
     lorentz(x-595, 1/pi) axes x1y2 lt rgb "red" title "15 Yellow Emission 595 nm"

set output "Sensitivity-16.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==16 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "16 Yellow Sensitivity VIS TLHY 4205", \
     lorentz(x-585, 1/pi) axes x1y2 lt rgb "red" title "16 Yellow Emission 585 nm"

set output "Sensitivity-17.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==17 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "17 Yellow-Green Sensitivity KBT L-7104MGC", \
     lorentz(x-574, 1/pi) axes x1y2 lt rgb "red" title "17 Yellow-Green Emission 574 nm"

set output "Sensitivity-18.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==18 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "18 Yellow-Green Sensitivity KBT L-7104GC", \
     lorentz(x-565, 1/pi) axes x1y2 lt rgb "red" title "18 Yellow-Green Emission 565 nm"

set output "Sensitivity-19.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==19 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "19 Green Sensitivity LED 3-14000 GN", \
     lorentz(x-520, 1/pi) axes x1y2 lt rgb "red" title "19 Green Emission 520 nm"

set output "Sensitivity-20.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==20 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "20 Red Sensitivity WUE 151034RS0300", \
     lorentz(x-628, 1/pi) axes x1y2 lt rgb "red" title "20 Red Emission 628 nm"

set output "Sensitivity-21.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==21 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "21 Green Sensitivity EVL 204-10 UBGC", \
     lorentz(x-502, 1/pi) axes x1y2 lt rgb "red" title "21 Green Emission 502 nm"

set output "Sensitivity-22.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==22 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "22 Turquoise Sensitivity RND 135-00151", \
     lorentz(x-500, 1/pi) axes x1y2 lt rgb "red" title "22 Turquoise Emission 500 nm"

set output "Sensitivity-23.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==23 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "23 Blue Sensitivity LED 3-3700 BL", \
     lorentz(x-465, 1/pi) axes x1y2 lt rgb "red" title "23 Blue Emission 465 nm"

set xrange[350:1000]

set output "Sensitivity-24.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==24 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "24 Infrared Sensitivity BPW 34", \
     lorentz(x-900, 1/pi) axes x1y2 lt rgb "red" title "24 Infrared Peak Sensitivity 900 nm"

set xrange[350:800]

set output "Sensitivity-25.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==25 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "25 Blue Sensitivity LED 3-2000 BL", \
     lorentz(x-465, 1/pi) axes x1y2 lt rgb "red" title "25 Blue Emission 465 nm"

set output "Sensitivity-26.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==26 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "26 Blue Sensitivity LED 3-3000 BL", \
     lorentz(x-458, 1/pi) axes x1y2 lt rgb "red" title "26 Blue Emission 458 nm"

set output "Sensitivity-27.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==27 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "27 Blueish Sensitivity EVL 1254UBC", \
     lorentz(x-428, 1/pi) axes x1y2 lt rgb "red" title "27 Blueish Emission 428 nm"

set output "Sensitivity-28.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==28 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "28 Ultraviolet Sensitivity LED LL 3-120 VI", \
     lorentz(x-400, 1/pi) axes x1y2 lt rgb "red" title "28 Ultraviolet Emission 400 nm"

set output "Sensitivity-29.svg"
plot "Sensitivity.dat" u (scale($1)):( ($2==29 ? current($3) : 1/0) ) with lp axes x1y1 pointtype 7 pointsize 0.2 lt rgb "blue" title "29 Green Sensitivity KBT L-7113ZGC", \
     lorentz(x-515, 1/pi) axes x1y2 lt rgb "red" title "29 Green Emission 515 nm"


